translate.misc.optrecurse

Package translate :: Package misc :: Module optrecurse |
[hide private]
[frames] | no frames]

# Module optrecurse

source code

Classes | [hide private]
| ManPageOption
| ManHelpFormatter
| RecursiveOptionParser A specialized Option Parser for recursing through directories.

Variables | [hide private]
| __package__ = ``'``translate.misc``'``

Imports: sys, os, fnmatch, traceback, optparse, StringIO, progressbar